# -*- coding: utf-8 -*-
"""
    ibuprofen
    ~~~~~~~~~~~~~~~~~~~

    Rendering HTML on server

    :copyright: 2020 ISCLUB
    :license: MIT LICENSE
"""


class OnlyText(object):
    def __init__(self, text):
        self.text = text


class Record(object):
    def __init__(self, recordname, body=[], classlist=[], attrs={}):
        self.recordname = recordname
        self.body = body
        self.classlist = classlist
        self.attrs = attrs

        if not isinstance(self.body, list):
            raise TypeError("Body must be a List.")

        if not isinstance(self.classlist, list):
            raise TypeError("Classlist must be a List.")

    def add(self, o):
        self.body.append(o)

    def add_attrs(self, name, value):
        self.attrs[name] = value

    def add_class(self, classname):
        self.classlist.append(classname)


class Pages(object):
    def __init__(self, body=[], head=[], attribute={}, css_static=[], lang="en"):
        self.body = body
        self.head = head
        self.css_static = css_static
        self.attribute = attribute
        self.lang = lang

    def add(self, o):
        self.body.append(o)

    def add_head(self, o):
        self.head.append(o)

    def add_attr(self, name, value):
        self.attribute[name] = value



# -*- coding: utf-8 -*-
"""
    ibuprofen
    ~~~~~~~~~~~~~~~~~~~

    Rendering HTML on server

    :copyright: 2020 ISCLUB
    :license: MIT LICENSE
"""
from .pages import Pages
from .pages import Record
from .pages import OnlyText

html_base = """
<!DOCTYPE html>
<html lang="{lang}">

<head>
    <meta charset="utf-8">
    <meta name="generator" content="Amantadine">
    {head}
</head>

<body>
    {body}
</body>

<style>
    {style}
</style>

</html>
"""

record_base = """
<{recordname} {classlist}{attrs}>
    {body}
</{recordname}>"""


def renderDoc(amantadineDoc: Pages):
    headString = ""
    for obj in amantadineDoc.head:
        headString = headString + renderRecord(obj) + " "

    bodyString = ""
    for obj in amantadineDoc.body:
        bodyString = bodyString + renderRecord(obj) + " "

    return html_base.format(
        lang=amantadineDoc.lang,
        head=headString,
        body=bodyString,
        style=amantadineDoc.css_static[0],
    )


def renderRecord(amantadineRecord: Record):
    if amantadineRecord.classlist == list():
        classString = ""
    else:
        classString = """class='"""
        for classname in amantadineRecord.classlist:
            classString = classString + classname + " "
        classString = classString + """'"""

    attrsString = ""
    for attrname, attrvalue in amantadineRecord.attrs.items():
        attrsString = attrname + "=" + attrvalue + " "

    bodyString = ""
    for obj in amantadineRecord.body:
        if isinstance(obj, Record):
            bodyString = bodyString + renderRecord(obj)
        elif isinstance(obj, OnlyText):
            bodyString = bodyString + obj.text
        else:
            pass

    return record_base.format(
        recordname=amantadineRecord.recordname,
        classlist=classString,
        attrs=attrsString,
        body=bodyString,
    )



# -*- coding: utf-8 -*-
"""
    ibuprofen
    ~~~~~~~~~~~~~~~~~~~

    Rendering HTML on server

    :copyright: 2020 ISCLUB
    :license: MIT LICENSE
"""
from .pages import Pages
from .pages import Record
from .pages import OnlyText
from .render import renderDoc
from .render import renderRecord
from .project import Project



from setuptools import setup, find_packages

setup(
    name="amantadine",
    version="0.0.4",
    packages=find_packages(),
    install_requires=[],
    url="https://github.com/isclub/amantadine",
    long_description=open("README.md", "r", encoding="utf-8").read(),
    license="MIT License",
    long_description_content_type="text/markdown",
    description="Amantadine is a framework for rendering HTML on the server",
)



# -*- coding: utf-8 -*-
"""
    ibuprofen
    ~~~~~~~~~~~~~~~~~~~

    Rendering HTML on server

    :copyright: 2020 ISCLUB
    :license: MIT LICENSE
"""
from .render import renderDoc
from .render import renderRecord
import os


class Project(object):
    def __init__(self, project_name, baserender, renderlist):
        self.project_name = project_name
        self.baserender = baserender
        self.renderlist = renderlist

    def render(self):
        print("🎍 Build Production ...")
        os.mkdir("docs")

        for view in self.renderlist:
            now_pagesname = view.view.recordname
            now_pagesDoc = self.baserender(title=view.title, body=view.view.body)
            now_path = view.path

            with open("docs/" + str(now_path) + ".html", "w+", encoding="utf-8") as f:
                f.write(renderDoc(now_pagesDoc))
        print(" ")
        print("All Chunk:")
        for pathfilename in os.listdir("docs/"):
            print(
                "docs/"
                + str(pathfilename)
                + " "
                + str(os.path.getsize("docs/" + str(pathfilename)))
                + "B"
            )



from amantadine import Record
from amantadine import OnlyText

title = "Welcome"
path = "index"

view = Record(
    recordname="hello",
    body=[Record("h2", body=[OnlyText("Welcome to You Amantadine App")])],
)

__all__ = ["title", "view", "path"]



from amantadine import Pages
from amantadine import Record
from amantadine import OnlyText
import requests

# Get CSS with Requests
gralig = requests.get("https://cdn.jsdelivr.net/npm/gralig@0.5.0/dist/gralig.min.css").text


def baserender(title, body):
    return Pages(
        body=[] + body + [],
        head=[Record("title", body=[OnlyText(title + " - Amantadine")])],
        css_static=[gralig],
    )
